"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractInterceptor = void 0;
const rest_1 = require("@loopback/rest");
const utils_1 = require("../helper/utils");
const entity_name_1 = require("./../models/entity-name");
class AbstractInterceptor {
    async getUriParts(invocationCtx) {
        const httpReq = (await invocationCtx.get(rest_1.RestBindings.Http.REQUEST, {
            optional: true,
        }));
        const protocol = await invocationCtx.get(rest_1.RestBindings.PROTOCOL, {
            optional: true,
        });
        const host = await invocationCtx.get(rest_1.RestBindings.HOST, {
            optional: true,
        });
        const port = await invocationCtx.get(rest_1.RestBindings.PORT, {
            optional: true,
        });
        const baseUrl = httpReq === null || httpReq === void 0 ? void 0 : httpReq.baseUrl;
        const path = httpReq === null || httpReq === void 0 ? void 0 : httpReq.path;
        const baseUri = protocol + '://' + host + ':' + port + baseUrl;
        const objectUri = path + ((path === null || path === void 0 ? void 0 : path.endsWith('/')) ? '' : '/');
        return {
            baseUri: baseUri,
            objectUri: objectUri,
        };
    }
    getEntityName(objectUri, baseUri) {
        const relativeObjectUri = objectUri.replace(baseUri, '');
        const entityUri = relativeObjectUri
            .substr('/' === relativeObjectUri.charAt(0) ? 1 : 0)
            .split('/')[0];
        const camelCase = utils_1.toCamelCase(entityUri.substr(0, entityUri.length - 1));
        return entity_name_1.EntityName[(camelCase.charAt(0) + camelCase.substr(1))];
    }
    getEntityUri(entityName) {
        switch (entityName) {
            case entity_name_1.EntityName.objectType:
            case 'subObjectType':
                return 'object-types';
            case entity_name_1.EntityName.objectNode:
            case 'parentNode':
            case 'parentAcl':
            case 'parentOwner':
            case 'parentNamespace':
            case 'parentTree':
                return 'object-nodes';
            default:
                if (entityName in entity_name_1.EntityName) {
                    return utils_1.toKebabCase(entityName) + 's';
                }
                return utils_1.toKebabCase(entityName);
        }
    }
}
exports.AbstractInterceptor = AbstractInterceptor;
//# sourceMappingURL=abstract.interceptor.js.map