"use strict";
var UriCompleteInterceptor_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.UriCompleteInterceptor = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/no-explicit-any */
const context_1 = require("@loopback/context");
const rest_1 = require("@loopback/rest");
const _ = tslib_1.__importStar(require("lodash"));
const utils_1 = require("../helper/utils");
const abstract_interceptor_1 = require("./abstract.interceptor");
const constants_1 = require("./constants");
/**
 * This class will be bound to the application as an `Interceptor` during
 * `boot`
 */
let UriCompleteInterceptor = UriCompleteInterceptor_1 = class UriCompleteInterceptor extends abstract_interceptor_1.AbstractInterceptor {
    /*
    constructor() {}
    */
    /**
     * This method is used by LoopBack context to produce an interceptor function
     * for the binding.
     *
     * @returns An interceptor function
     */
    value() {
        return this.intercept.bind(this);
    }
    /**
     * The logic to intercept an invocation
     * @param invocationCtx - Invocation context
     * @param next - A function to invoke next interceptor or the target method
     */
    async intercept(invocationCtx, next) {
        const result = await next();
        try {
            const httpReq = await invocationCtx.get(rest_1.RestBindings.Http.REQUEST, {
                optional: true,
            });
            const method = httpReq === null || httpReq === void 0 ? void 0 : httpReq.method;
            if ('GET' === method || 'POST' === method || 'PATCH' === method) {
                const uriParts = await this.getUriParts(invocationCtx);
                this.addUri(result, uriParts.baseUri, uriParts.objectUri);
            }
            // eslint-disable-next-line no-empty
        }
        catch (error) { }
        return result;
    }
    addUri(
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    result, baseUri, objectUri, deep = 0) {
        if (deep > 2) {
            return;
        }
        if (_.isArray(result)) {
            result.forEach((item) => {
                this.addUri(item, baseUri, objectUri, deep);
            });
        }
        else if (_.isObject(result)) {
            if ('entityName' in result) {
                deep = 0;
                objectUri =
                    '/' +
                        this.getEntityUri(result.entityName) +
                        '/';
                delete result.entityName;
            }
            if ('id' in result) {
                result.uri =
                    baseUri + objectUri + result.id;
            }
            Object.keys(result).forEach((key) => {
                if (_.isObject(result[key]) ||
                    _.isArray(result[key])) {
                    this.addUri(result[key], baseUri, `${objectUri}${result.id}/${this.getEntityUri(key)}/`, deep + 1);
                }
                else if (_.isString(result[key]) &&
                    key.endsWith('Id')) {
                    const field = key.substr(0, key.length - 2);
                    const entityUri = this.getEntityUri(field);
                    if (entityUri === utils_1.toKebabCase(field)) {
                        result[field + 'Uri'] = `${baseUri}/${objectUri}${result.id}/${entityUri}/${result[key]}`;
                    }
                    else {
                        result[field + 'Uri'] = `${baseUri}/${entityUri}/${result[key]}`;
                    }
                }
            });
        }
    }
};
UriCompleteInterceptor.BINDING_KEY = `interceptors.${UriCompleteInterceptor_1.name}`;
UriCompleteInterceptor = UriCompleteInterceptor_1 = tslib_1.__decorate([
    context_1.globalInterceptor(constants_1.URI_INTERCEPTOR, {
        tags: { name: UriCompleteInterceptor_1.BINDING_KEY },
    })
], UriCompleteInterceptor);
exports.UriCompleteInterceptor = UriCompleteInterceptor;
//# sourceMappingURL=uri-complete.interceptor.js.map