import { DataObject } from '@loopback/repository';
import { Principal } from '@loopback/security';
import { ObjectNode } from '../models/object-node.model';
import { ObjectSubType } from '../models/object-sub-type.model';
import { ObjectType } from '../models/object-type.model';
import { ObjectTree } from './../models/object-tree.model';
import { AccessRightPermissions } from './access-rights/access-rights.const';
export declare class NodeContext {
    node: ExpectedValue<ObjectNode>;
    parent: ExpectedValue<ObjectNode>;
    parentType: ExpectedValue<ObjectType>;
    objectSubType: ExpectedValue<ObjectSubType>;
    objectType: ExpectedValue<ObjectType>;
}
export declare class TreeContext {
    treeNode: ExpectedValue<ObjectNode>;
}
export declare class AccessRightsContext {
    rights: ExpectedValue<AccessRightPermissions>;
    user: ExpectedValue<Principal>;
    treeRootNodeId: ExpectedValue<string>;
    aclTrees: ExpectedValue<{
        [aclId: string]: ObjectTree;
    }>;
}
export declare class TypeContext {
    types: ExpectedValue<{
        [id: string]: ObjectType;
    }>;
}
export declare class CurrentContext {
    nodeContext: NodeContext;
    treeContext: TreeContext;
    accessRightsContexte: AccessRightsContext;
    typeContext: TypeContext;
    static get(value: DataObject<CurrentContext>): CurrentContext;
    [key: string]: any;
}
export declare const CURRENT_CONTEXT = "CURRENT_CONTEXT";
export declare class ExpectedValue<T> {
    private _value;
    private resolveValue;
    constructor(value?: T);
    waitForValue: Promise<T>;
    get value(): T;
    set value(value: T);
    getOrSetValue(searchValue: () => Promise<T>): Promise<T>;
}
export declare enum ObjectTypeName {
    ROOT = "root",
    USER = "User",
    ANONYMOUS_USER = "AnonymousUser",
    ACCESS_RIGHT_DEFINITION = "AccessRightDefinition",
    ACCESS_RIGHT_GROUP = "AccessRightGroup",
    ACCESS_RIGHT_OWNERS = "AccessRightOwners",
    ACCESS_RIGHT_ACCESS_MANAGERS = "AccessRightAccessManagers",
    TENANT = "Tenant"
}
export declare class ApplicationService {
    static OBJECT_TYPE_NAMES: typeof ObjectTypeName;
    static OBJECT_NODE_NAMES: {
        [objectType in ObjectTypeName]: string;
    };
    static CONTENT_TYPE: {
        USER: string;
        JSON: string;
    };
    rootType: ExpectedValue<ObjectType>;
    tenantType: ExpectedValue<ObjectType>;
    rooteNode: ExpectedValue<ObjectNode>;
    userType: ExpectedValue<ObjectType>;
    anonymousUserType: ExpectedValue<ObjectType>;
    accessRightsDefinitionType: ExpectedValue<ObjectType>;
    accessRightsGroupType: ExpectedValue<ObjectType>;
    accessRightsOwnersType: ExpectedValue<ObjectType>;
    accessRightsAccessManagersType: ExpectedValue<ObjectType>;
    ready: Promise<unknown>;
}
