import { DataObject, FilterExcludingWhere, Options } from '@loopback/repository';
import { ObjectNode } from '../models';
import { ObjectNodeRepository } from '../repositories';
import { ObjectNodeRelations } from './../models/object-node.model';
import { ObjectType } from './../models/object-type.model';
import { CurrentContext } from './application.service';
import { ContentEntityService } from './content-entity.service';
import { ObjectTypeService } from './object-type.service';
export declare enum ParentNodeType {
    node = "node",
    tree = "tree",
    owner = "owner",
    namespace = "namespace"
}
export declare class ObjectNodeService {
    objectNodeRepository: ObjectNodeRepository;
    objectTypeService: ObjectTypeService;
    contentEntityService: ContentEntityService;
    constructor(objectNodeRepository: ObjectNodeRepository, objectTypeService: ObjectTypeService, contentEntityService: ContentEntityService);
    searchByTreeId(treeId: string): Promise<ObjectNode[]>;
    searchByTreeIds(treeIds: string[]): Promise<ObjectNode[]>;
    searchByParentIdAndObjectTypeId(parentNodeId: string, objectTypeId: string): Promise<ObjectNode[]>;
    searchByParentIdsAndObjectTypeId(parentNodeIds: string[], objectTypeId: string): Promise<ObjectNode[]>;
    searchOwner(ownerType: string, ownerName: string): Promise<ObjectNode>;
    searchNamespace(ownerType: string, ownerName: string, namespaceType: string, namespaceName: string): Promise<ObjectNode>;
    getOrCreateChildren(parentId: string, objectTypeId: string, defaultValue?: DataObject<ObjectNode>, min?: number): Promise<ObjectNode[]>;
    searchTreeNode(ownerType: string, ownerName: string, namespaceType: string, namespaceName: string, treeType: string, treeName: string): Promise<ObjectNode>;
    searchById(id: string, filter?: FilterExcludingWhere<ObjectNode>, options?: Options): Promise<ObjectNode & ObjectNodeRelations>;
    protected checkNameAvailibility(objectNode: DataObject<ObjectNode>, name: string): Promise<void>;
    private checkBrothersCondition;
    private checkSubTypesCondition;
    add(objectNode: DataObject<ObjectNode>, ctx: CurrentContext, byPassCheck?: boolean): Promise<ObjectNode>;
    protected getPropertiesKeys(objectType: ObjectType, objectKeys?: string[]): string[];
    modifyById(id: string, objectNode: DataObject<ObjectNode>, ctx: CurrentContext): Promise<ObjectNode>;
    protected getParentIdKey(parentType: ParentNodeType): string;
    removeByParent(parentType: ParentNodeType, id: string): Promise<void>;
    removeById(id: string, ctx: CurrentContext): Promise<void>;
}
